@@ -1,3 +1,5 @@
+from logging import getLogger
+
 from debug_toolbar.panels import Panel
 from django.template.loader import render_to_string
 from django.utils.translation import gettext_lazy as _
@@ -9,6 +11,8 @@ try:
 except ImportError:
     uwsgi = None
 
+logger = getLogger(__name__)
+
 
 class UwsgiWorkersPanel(Panel):
     nav_title = title = _('uWSGI Workers')
@@ -26,12 +30,13 @@ class UwsgiWorkersPanel(Panel):
         return uwsgi
 
     def generate_stats(self, request, response):
-        view = UwsgiWorkers()
-        view.setup(request)
-        try:
-            self.record_stats(view.get_context_data())
-        except Exception as exc:
-            print(exc)
+        if uwsgi:
+            view = UwsgiWorkers()
+            view.setup(request)
+            try:
+                self.record_stats(view.get_context_data())
+            except Exception as exc:
+                logger.exception('Failed generating UwsgiWorkersPanel stats: %s', exc)
 
 
 class UwsgiActionsPanel(Panel):
